#!/usr/bin/env python3
""" List of shortcuts for tags with (nearly) only one attribute"""

XSLT_TAGS_ONE_ATTRIBUTE = {
    'when': 'test',
    'if': 'test',
    'for-each': 'select',
    'call-template': 'name',
    'include': 'href',
    'import': 'href',
    'copy': 'use-attribute-sets',
    'copy-of': 'select',
    'message': 'terminate',
    'preserve-space': 'elements',
    'strip-space': 'elements',
    'text': 'disable-output-escaping',
    'value-of': 'select',
    'apply-templates': 'select',
    'template': 'name',
    'attribute': 'name',
    'match': 'match',
}

